<!--
Commented sections (like this) are meant to be explanatory. Feel free to delete them.

To create IDRs without these comments:
- Use the --no-comments flag: idr new "Title" --no-comments
- Or set the environment variable: export IDR_NO_COMMENTS=1
-->

# {{ date }}: {{ title }}

Owner: {{ owner }}

## Overview

### Problem Statement

<!--
* 3-5 lines
* Statement of the goal
* Help people decide if they want to invest in reading this on a skim
-->

### Context (as needed)

### Goals

<!--
* Describe major goals of this implementation
* Does not need to be exhaustive, less is more
-->

### Non-Goals

<!--
* Describe non-goals of this implementation
* Does not need to be exhaustive, less is more
-->

### Proposed Solution

<!--
Describe in relatively short form (ideally <200 words) the proposed solution
-->

## Detailed Design (as needed)

<!--
Go into more detail on the design if needed. Totally optional. Note there
is a section below for describing the exact shape of the implementation.
-->

## Cross cutting concerns (as needed)

<!--
Describe the design from other angles, as required: security, reliability, etc.
-->

## Alternatives considered (as needed)

<!--
Describe alternatives to this design that were considered. Doesn't need to
be exhaustive, only add something here if you think someone is likely to ask
about it.
-->

## Future plans (as needed)

<!--
Things that may be added in the future
-->

## Other reading (as needed)

<!--
Provide links to prior art
-->

## Implementation (ephemeral)

<!--
Details on the implementation of this design. Can include checklists,
detailed descriptions of code changes, etc. Whatever is most helpful
to the humans and/or computers responsible for implementation!
-->
